import {Component, ElementRef, ViewChild} from '@angular/core';
import * as Parse from "parse";
import {NzMessageService} from 'ng-zorro-antd/message';

(Parse as any).serverURL = "https://web2023.fmode.cn/parse";
// https://web2023.fmode.cn/s0210490/api/user/login
Parse.initialize("dev")

@Component({
  selector: 'app-interview-history',
  templateUrl: './interview-history.component.html',
  styleUrls: ['./interview-history.component.scss']
})
export class InterviewHistoryComponent {
  constructor(private message: NzMessageService) {
  }

  async ngOnInit() {
    this.history = await this.searchHistory();
    console.log(this.history)
  }

  //是否加载到历史数据
  createBasicMessage(message: string): void {
    this.message.info(message);
  }

  //初始化数据
  async searchHistory(): Promise<any[]> {
    let query = new Parse.Query("LjUserInterviewData");
    let user: any = Parse.User.current()
    query.equalTo('user', user);
    query.equalTo('interviewResult', 0)
    query.descending('updatedAt');
    query.limit(5);
    query.skip(this.skip)
    try {
      const results = await query.find();
      if (results.length > 0) {
        console.log(results);
        return results;
      } else {
        this.createBasicMessage("历史数据查询失败");
        setTimeout(() => {
        }, 1000);
      }
    } catch (e) {
      console.log(e);
    }
    return [];

  }

  //转换日期时间
  convertTimeFormat(time: string) {
    const date = new Date(time);
    const month = date.getMonth() + 1;
    const day = date.getDate();
    return `${month}月${day}日`
  }

  //触底加载逻辑
  @ViewChild('container') container!: ElementRef;

  async onScroll() {
    const scrollTop = this.container.nativeElement.scrollTop;
    const scrollHeight = this.container.nativeElement.scrollHeight;
    const clientHeight = this.container.nativeElement.clientHeight;

    if (scrollTop + clientHeight >= scrollHeight) {
      // 滚动条触底，执行相应的方法
      console.log("触底")
      await this.onBottomLoad();
    }
  }

  skip: number = 0;//跳过多少条加载
  async onBottomLoad() {
    this.createBasicMessage("历史数据获取中");
    setTimeout(async () => {
      this.skip = this.history.length;
      let list = await this.searchHistory();
      this.history = this.history.concat(list)
    }, 1000)

  }

  history!: any[];
  //删除确认框逻辑
  isVisible = false;


  showModal(): void {
    this.isVisible = true;
  }

  handleOk(): void {
    console.log('Button ok clicked!');
    this.isVisible = false;
  }

  handleCancel(): void {
    console.log('Button cancel clicked!');
    this.isVisible = false;
  }

}
